package com.community.huiju.controller;


import com.community.commom.mode.ResponseBean;
import com.community.commom.session.UserElement;
import com.community.huiju.common.base.BaseController;
import com.community.huiju.model.BuildingOwnerInfo;
import com.community.huiju.service.IBuildingOwnerInfoService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpSession;
import java.util.List;
import java.util.stream.Collectors;

/**
 * <p>
 * 楼栋业主资料信息表 前端控制器
 * </p>
 *
 * @author weiximei
 * @since 2018-12-18
 */
@RestController
@RequestMapping("/")
@Api(value = "楼栋业主资料信息", description = "楼栋业主资料信息 Api")
public class BuildingOwnerInfoController extends BaseController {

    @Autowired
    private IBuildingOwnerInfoService iBuildingOwnerInfoService;

    @ApiOperation(value = "获取楼栋业主信息", notes = "根据条件获取")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataTypeClass = String.class, name = "parameter",value = "building栋;" +
                    "unit单元;level楼层;roomNo户号;" +
                    "ownerName业主姓名;" +
                    "pageNum第几页;pageSize 一页多少行;")
    })
    @RequestMapping(value = "/building/list", method = RequestMethod.POST)
    public ResponseBean getList(@RequestBody String parameter){
        ResponseBean responseBean = new ResponseBean();
        responseBean = iBuildingOwnerInfoService.listQuery(parameter);
        return responseBean;
    }

    @ApiOperation(value = "修改楼栋业务信息", notes = "修改楼栋业主信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataTypeClass = String.class, name = "parameter",value = "id编号;building栋;" +
                    "unit单元;level楼层;roomNo户号;" +
                    "ownerName业主姓名;" +
                    "ownerTel业主手机号"),
            @ApiImplicitParam(paramType = "header", dataTypeClass = String.class, name = "X-Auth-Token", value = "token")
    })
    @RequestMapping(value = "/building/update", method = RequestMethod.PUT)
    public ResponseBean update(@RequestBody String parameter, HttpSession session){
        ResponseBean responseBean = new ResponseBean();
        UserElement userElement = getUserElement(session);
        responseBean = iBuildingOwnerInfoService.update(parameter,userElement.getId());
        return responseBean;
    }

    @ApiOperation(value = "添加楼栋业务信息", notes = "添加楼栋业务信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataTypeClass = String.class, name = "parameter", value = "id编号;building栋;" +
                    "unit单元;level楼层;roomNo户号;" +
                    "ownerName业主姓名;" +
                    "ownerTel业主手机号"),
            @ApiImplicitParam(paramType = "header", dataTypeClass = String.class, name = "X-Auth-Token", value = "token")
    })
    @RequestMapping(value = "/building/add", method = RequestMethod.POST)
    public ResponseBean add(@RequestBody String parameter, HttpSession session){
        ResponseBean responseBean = new ResponseBean();
        UserElement userElement = getUserElement(session);
        responseBean = iBuildingOwnerInfoService.add(parameter,userElement.getId());
        return responseBean;
    }

    @ApiOperation(value = "批量删除楼栋业主信息", notes = "批量删除楼栋业主信息")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataTypeClass = String.class, name = "ids",value = "id集合"),
            @ApiImplicitParam(paramType = "header", dataTypeClass = String.class, name = "X-Auth-Token", value = "token")
    })
    @RequestMapping(value = "/building/delete", method = RequestMethod.DELETE)
    public ResponseBean delete(@RequestBody List<Integer> ids, HttpSession session){
        ResponseBean responseBean = new ResponseBean();
        UserElement userElement = getUserElement(session);
        List<BuildingOwnerInfo> infoList = ids.stream().map(e->{
            BuildingOwnerInfo buildingOwnerInfo = new BuildingOwnerInfo();
            buildingOwnerInfo.setId(e);
            buildingOwnerInfo.setVerifyStatus("2");
            buildingOwnerInfo.setUpdateUser(userElement.getId());
            return buildingOwnerInfo;
        }).collect(Collectors.toList());
        boolean result = iBuildingOwnerInfoService.updateBatchById(infoList);
        if (result) {
            responseBean.addSuccess("操作成功!");
        }else {
            responseBean.addError("操作失败!");
        }
        return responseBean;
    }

    @ApiOperation(value = "查询 楼栋/单元/楼层/户号", notes = "查询 楼栋/单元/楼层/户号")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "body", dataTypeClass = String.class, name = "parameter", value = "building楼层;" +
                    "unit单元;level楼层;roomNo户号")
    })
    @RequestMapping(value = "/building/info",method = RequestMethod.POST)
    public ResponseBean buildingUnitNumber(@RequestBody String parameter, HttpSession session){
        ResponseBean responseBean = new ResponseBean();
        UserElement userElement = getUserElement(session);
        responseBean = iBuildingOwnerInfoService.getBuildingOrUnitOrNumber(parameter, userElement.getCommunityId());
        return responseBean;
    }

}
