package com.community.huiju.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.enums.SqlMethod;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.community.commom.mode.ResponseBean;
import com.community.commom.utils.BeanTools;
import com.community.huiju.dao.BuildingOwnerInfoMapper;
import com.community.huiju.exception.WisdomException;
import com.community.huiju.model.BuildingOwnerInfo;
import com.community.huiju.service.IBuildingOwnerInfoService;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import lombok.extern.slf4j.Slf4j;
import org.apache.ibatis.binding.MapperMethod;
import org.apache.ibatis.session.SqlSession;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 楼栋业主资料信息表 服务实现类
 * </p>
 *
 * @author weiximei
 * @since 2018-12-18
 */
@Service("iBuildingOwnerInfoService")
@Slf4j
public class BuildingOwnerInfoServiceImpl extends ServiceImpl<BuildingOwnerInfoMapper, BuildingOwnerInfo> implements IBuildingOwnerInfoService {

    @Autowired
    private BuildingOwnerInfoMapper buildingOwnerInfoMapper;

    @Override
    public ResponseBean listQuery(String parameter) {

        ResponseBean responseBean = new ResponseBean();

        JSONObject jsonObject = JSONObject.parseObject(parameter);
        BuildingOwnerInfo buildingOwnerInfo = jsonObject.toJavaObject(BuildingOwnerInfo.class);

        Long pageNum = jsonObject.getLong("pageNum") == null ? 1 : jsonObject.getLong("pageNum");
        Long pageSize = jsonObject.getLong("pageSize") == null ? 10 : jsonObject.getLong("pageSize");

        Page<BuildingOwnerInfo> page = new Page(pageNum,pageSize);

        Map<String, Object> map = Maps.newHashMap();
        // 栋
        map.put("building",buildingOwnerInfo.getBuilding());
        // 单元
        map.put("unit",buildingOwnerInfo.getUnit());
        // 楼层
        map.put("level",buildingOwnerInfo.getLevel());
        // 房号
        map.put("room_no",buildingOwnerInfo.getRoomNo());

        QueryWrapper<BuildingOwnerInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.allEq(map,false);
        queryWrapper.like(buildingOwnerInfo.getOwnerName() != null,"owner_name",buildingOwnerInfo.getOwnerName());

        // 分页查询
        IPage<BuildingOwnerInfo> infoIPage = buildingOwnerInfoMapper.selectPage(page, queryWrapper);


        Map<String, Object> retMap = Maps.newHashMap();
        // 获取数据
        List<BuildingOwnerInfo> list = infoIPage.getRecords();

        retMap.put("data", list);
        retMap.put("total", infoIPage.getTotal());
        retMap.put("pageNum", infoIPage.getCurrent());
        retMap.put("pageSize", infoIPage.getSize());

        responseBean.addSuccess(list);

        return responseBean;
    }


    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResponseBean update(String parameter, Integer userId) {
        ResponseBean responseBean = new ResponseBean();

        BuildingOwnerInfo buildingOwnerInfo = JSONObject.parseObject(parameter, BuildingOwnerInfo.class);
        BuildingOwnerInfo oldBuildingOwnerInfo = buildingOwnerInfoMapper.selectById(buildingOwnerInfo.getId());
        if (null == oldBuildingOwnerInfo) {
            throw new WisdomException("%s 数据不存在!", buildingOwnerInfo.getId());
        }

        BeanTools.copyProperties(buildingOwnerInfo, oldBuildingOwnerInfo);

        oldBuildingOwnerInfo.setUpdateDate(LocalDateTime.now());
        oldBuildingOwnerInfo.setUpdateUser(userId);

        int row = buildingOwnerInfoMapper.updateById(oldBuildingOwnerInfo);
        if (row <= 0) {
            throw new WisdomException("操作失败!");
        } else {
            responseBean.addSuccess("操作成功!");
        }
        return responseBean;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResponseBean add(String parameter, Integer userId) {
        ResponseBean responseBean = new ResponseBean();

        BuildingOwnerInfo buildingOwnerInfo = JSONObject.parseObject(parameter, BuildingOwnerInfo.class);
        // 主键是自增的, 所以设置为 null
        buildingOwnerInfo.setId(null);
        buildingOwnerInfo.setUpdateUser(userId);
        buildingOwnerInfo.setUpdateDate(LocalDateTime.now());
        buildingOwnerInfo.setCreateDate(LocalDateTime.now());
        buildingOwnerInfo.setCreateUser(userId);

        int row = buildingOwnerInfoMapper.insert(buildingOwnerInfo);
        if (row <= 0) {
            throw new WisdomException("操作失败!");
        } else {
            responseBean.addSuccess("操作成功!");
        }

        return responseBean;
    }

    @Override
    public ResponseBean getBuildingOrUnitOrNumber(String parameter,Integer communityId) {

        ResponseBean responseBean = new ResponseBean();
        if (null == communityId || "".equals(communityId)) {
            throw new WisdomException("编号:%s 小区不存在!", communityId);
        }

        BuildingOwnerInfo buildingOwnerInfo = JSONObject.parseObject(parameter, BuildingOwnerInfo.class);

        Map<String, Object> map = Maps.newHashMap();

        // 小区
        map.put("community_id", communityId);
        // 栋
        map.put("building",buildingOwnerInfo.getBuilding());
        // 单元
        map.put("unit",buildingOwnerInfo.getUnit());
        // 楼层
        map.put("level",buildingOwnerInfo.getLevel());

        QueryWrapper<BuildingOwnerInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.allEq(map, false);

        /**
         * 1.如果 楼栋值不存在表示根据小区Id查询时查询楼栋!
         * 2.如果 楼栋存在表示查询单元
         * 3.如果 单元存在表示查询楼层
         * 4.如果 楼层存在表示查询户号
         *
         * 查询户号, 依赖于前面的查询条件成立!
         *
         * 这里的查询都依赖于, 前面的查询条件成立! 比如 要使用条件2, 那么条件1 必须成立!
         *
         */

        String column = null;
        if (null == buildingOwnerInfo.getBuilding()) {
            column = "building";
        } else if (null == buildingOwnerInfo.getUnit()) {
            column = "unit";
        } else if (null == buildingOwnerInfo.getLevel()){
            column = "level";
        } else if (null == buildingOwnerInfo.getRoomNo()) {
            column = "room_no";
        }
        queryWrapper.groupBy(column);
        List<BuildingOwnerInfo> selectList = buildingOwnerInfoMapper.selectList(queryWrapper);

        responseBean.addSuccess(selectList);

        return responseBean;
    }
}
