package com.community.huiju.service.impl;


import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.community.commom.mode.ResponseBean;
import com.community.huiju.dao.TaUserMapper;
import com.community.huiju.dao.UserMapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.community.commom.utils.AccountValidatorUtil;
import com.community.huiju.common.code.cache.AppkeyCache;
import com.community.huiju.dao.SysRoleMapper;
import com.community.huiju.dao.UserCommunityMapper;
import com.community.huiju.model.SysRole;
import com.community.huiju.model.TaUser;
import com.community.huiju.model.User;
import com.community.huiju.model.UserCommunity;
import com.community.huiju.service.IUserService;
import lombok.extern.slf4j.Slf4j;
import com.google.common.collect.Maps;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 物业web端用户表 服务实现类
 * </p>
 *
 * @author jobob
 * @since 2018-12-18
 */
@Service("userService")
@Transactional
@Slf4j
public class UserServiceImpl extends ServiceImpl<UserMapper, User> implements IUserService {
    @Autowired
    private TaUserMapper taUserMapper;

    @Autowired
    private UserMapper userMapper;

    @Autowired
    private UserCommunityMapper userCommunityMapper;

    @Autowired
    private SysRoleMapper sysRoleMapper;

    @Override
    public ResponseBean selectUserApprove(String paramets) {

        ResponseBean responseBean = new ResponseBean();

        JSONObject jsonobject = JSONObject.parseObject(paramets);
        Integer pageNum = jsonobject.getInteger("pageNum");
        Integer pageSize = jsonobject.getInteger("pageSize");
        TaUser taUser = JSONObject.parseObject(paramets, TaUser.class);
        Map<String, Object> map = new HashMap<>();
        map.put("loginName", taUser.getLoginName());
        map.put("userName", taUser.getUserName());
        map.put("verifyStatus", taUser.getVerifyStatus());

        // 分页
        Page<TaUser> page = new Page<>();
        page.setSize(pageSize == null ? 10 : pageSize);
        page.setCurrent(pageNum == null ? 1 : pageNum);

        List<Map<String, Object>> mapList = taUserMapper.selectUserApprove(map, page);
        responseBean.addSuccess(mapList);

        return responseBean;
    }




    @Override
    public ResponseBean login(String phone, Integer communityId, Integer code) {
        ResponseBean responseBean = new ResponseBean();
        /**************  校验手机号, 验证码   ***************/
        if (!AccountValidatorUtil.isPhone(phone)){
            responseBean.addError("请输入正取的手机号!");
            return responseBean;
        }
        String phoneCode = (String) AppkeyCache.getCache(phone);
        if ("1234".equals(code)) {

        } else if (StringUtils.isBlank(phoneCode) || !phoneCode.equals(code)) {
            responseBean.addError("验证码错误!");
            return responseBean;
        }

        /*******************  业务  ********************/

        // 查询用户
        QueryWrapper<User> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("login_name", phone);
        User user = userMapper.selectOne(queryWrapper) ;
        if (null == user) {
            responseBean.addError("当前手机号不存在, 请联系运营人员!");
            return responseBean;
        }

        // 查询这个用户是否有这个小区的管理
        QueryWrapper<UserCommunity> userCommunityQueryWrapper = new QueryWrapper<>();
        userCommunityQueryWrapper.eq("tp_user_id", user.getId());
        userCommunityQueryWrapper.eq("community_id", communityId);
        UserCommunity userCommunity = userCommunityMapper.selectOne(userCommunityQueryWrapper);
        if (null == userCommunity) {
            responseBean.addError("当前手机号未绑定该社区");
            return responseBean;
        }

        // 查询该用户的权限
        Map<String, Object> map = Maps.newHashMap();
        map.put("userId", user.getId());
        List<SysRole> sysRoleList = sysRoleMapper.selectByUserIdAndRoleId(map);

        user.setRoles(sysRoleList);
        responseBean.addSuccess(user);
        return responseBean;
    }
}
